@@ -37,6 +37,7 @@
 #include <mail/em-config.h>
 #include <mail/em-event.h>
 #include <mail/em-folder-tree.h>
+#include <mail/em-folder-tree-model.h>
 #include <mail/em-folder-selector.h>
 #include <e-gw-connection.h>
 #include <share-folder.h>
@@ -178,7 +179,7 @@ apply_clicked (GtkAssistant *assistant, CamelMimeMessage *msg)
 	accept_data = g_new0 (struct AcceptData, 1);
 
 	dialog = em_folder_selector_create_new (
-		parent, E_MAIL_BACKEND (shell_backend), 0,
+		parent, E_MAIL_BACKEND (shell_backend), em_folder_tree_model_get_default (), 0,
 		_("Create folder"), _("Specify where to create the folder:"));
 
 	selector = EM_FOLDER_SELECTOR (dialog);
