@@ -493,9 +493,9 @@ proxy_get_cnc (EAccount *account, GtkWindow *parent_window)
 	prompt = g_strdup_printf (_("%sEnter password for %s (user %s)"),
 			failed_auth, poa_address, url->user);
 
-	password = e_passwords_get_password ("Groupwise", key);
+	password = e_passwords_get_password (NULL, key);
 	if (!password)
-		password = e_passwords_ask_password (prompt, "Groupwise", key, prompt,
+		password = e_passwords_ask_password (prompt, NULL, key, prompt,
 				E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET, &remember, parent_window);
 	g_free (prompt);
 
